@@ -6,7 +6,8 @@ class Locale:
     peculiar to the machine wielder is running on.
     """
 
-    def __init__(self, project_root, super_project_root, module_root, code_path, datastores_root):
+    def __init__(self, project_root, super_project_root, module_root, code_path, datastores_root,
+                 provision_root='unknown'):
         """
 
         :param project_root: The wielder project wrapping CICD of code
@@ -14,6 +15,7 @@ class Locale:
         :param module_root: The local Path to service CICD module
         :param code_path: The local Path to service code module
         :param datastores_root: 3rd party datastore CICD path
+        :param provision_root: provision (Terraform root)
         """
 
         self.project_root = project_root
@@ -21,7 +23,7 @@ class Locale:
         self.module_root = module_root
         self.code_path = code_path
         self.datastores_root = datastores_root
-
+        self.provision_root = provision_root
 
 
 
